require 'minitest/autorun'
require 'mocha/minitest'
require 'converter'
require 'api_gateway'
require 'diffy'

class QontoOfxTest < Minitest::Test
  def setup
    QontoOfx::ApiGateway.any_instance
      .stubs(:fetch_organization)
      .returns(JSON.parse(
        File.readlines('./test/sample/organization/valid_two_accounts.txt').join
      ))

    stub_transactions(
      'https://thirdparty.qonto.eu/v2/transactions?slug=corp-1234-bank-account-1&iban=FR0000000000000000000000001',
      './test/sample/transactions/corp-1234-bank-account-1-FR0000000000000000000000001.txt'
    )
    stub_transactions(
      'https://thirdparty.qonto.eu/v2/transactions?slug=corp-1234-bank-account-2&iban=FR0000000000000000000000002',
      './test/sample/transactions/corp-1234-bank-account-2-FR0000000000000000000000002-p1.txt'
    )
    stub_transactions(
      'https://thirdparty.qonto.eu/v2/transactions?slug=corp-1234-bank-account-2&iban=FR0000000000000000000000002&page=2',
      './test/sample/transactions/corp-1234-bank-account-2-FR0000000000000000000000002-p2.txt'
    )
    @converter = QontoOfx::Converter.new('SLUG', 'TOKEN')
    Time.stubs(:now).returns(Time.new(2018, 07, 10))
  end

  def stub_transactions(url, file)
    QontoOfx::ApiGateway.any_instance
      .stubs(:fetch_transactions)
      .with(url)
      .returns(JSON.parse(
        File.readlines(file).join
      ))
  end

  def test_convert
    result = @converter.convert

    diff = Diffy::Diff.new(
      File.readlines('test/sample/ofx/test_result.xml').join,
      result
    ).to_s(:color).chomp
    puts diff unless diff.empty?

    assert diff.empty?
  end
end
